[![code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![docs: passing](https://readthedocs.org/projects/tabletoppy/badge/?version=latest)](https://tabletoppy.readthedocs.io/en/latest/?badge=latest)

# Tabletoppy

A Python library for simulating tabletop games, including dice rolls, coin tosses etc.
